import settings

HIERARCHICAL_ALGORITHMS = [
    ("hierarchical_spectral", "hs"),
    ("single_linkage", "sl"),
    ("hierarchical_so_heuristic", "hash"),
    ("hierarchical_so", "has"),
    ("hierarchical_kmeans", "hkm"),
    ("hierarchical_active_kmeans", "hakm")
]

"""
A DataLoader object provides an interface for reading the outputs of the various
experiments. By specifying the type of the DataLoader, you explicitly tell it
what experiment data you are interested in loading.
"""

class DataLoader(object):
    def __init__(self, type):
        """
        Constructor. type can be one of "thresholds" "runtime" "probes" "outlier"
        """
        self.type = type
        self.data = []
        self.xaxis = None
        self.xlabel = ""

    def read_data(self, params={}):
        """
        Load data for any type other than thresholds. This loads the data for
        each algorithm into self.data.
        """
        if self.type == "thresholds":
            raise Exception("read_data called on DataLoader with type 'thresholds'. Use read_thresholds instead")

        self.data = []
        for alg in HIERARCHICAL_ALGORITHMS:
            fstr = settings.OUTDIR+"/%s_%s" % (alg[0], self.type)
            if 'n' in params.keys():
                fstr += "_n=%d" % (params['n'])
            if 'matrix' in params.keys():
                fstr += "_%s" % (params['matrix'])
            fstr += ".out"
            f = open(fstr)
            lines = f.readlines()

            xaxis = lines[0].strip()
            xaxis = xaxis.split(" ")
            self.xlabel = xaxis[0]
            xaxis = xaxis[1:len(xaxis)]

            if self.xaxis == None:
                self.xaxis = xaxis
            else:
                ## check if this guy has the same xaxis parameters
                if (self.xaxis != xaxis):
                    print "WARNING: different xaxes"

            means = lines[1].strip()
            means = means.split(" ")
            means = means[1:len(means)]

            vars = lines[2].strip()
            vars = vars.split(" ")
            vars = vars[1:len(vars)]
            
            self.data.append((means, vars))

    def read_thresholds(self, alg, params={}):
        """
        Read in data for threshold curves. This additionally requires a string
        specifying the algorithm name. As of now it doesn't use any additional
        parameters.
        """
        self.data = []
        f = open(settings.OUTDIR+"/%s_tc_n_um.out" % (alg))
        lines = f.readlines()
        
        xaxis = lines[0].strip()
        xaxis = xaxis.split(" ")
        self.xlabel = xaxis[0]
        xaxis = xaxis[1:len(xaxis)]
        self.xaxis = xaxis
        self.xlabel = "Noise Variance"

        for line in lines[1:len(lines)]:
            tmp = line.strip().split(" ")
            self.data.append((int(tmp[0]), [float(x) for x in tmp[1:len(tmp)]]))
        
        
