import alg_names, DataLoader, settings
import numpy as np
import copy
import matplotlib.pyplot as plt
from matplotlib import rc, mlab
from matplotlib import font_manager

rc('font',**{'family':'sans-serif','sans-serif':['Helvetica']})
rc('text', usetex=True)


"""
Class for plotting threshold curves.
"""
class PlotThresholds(object):
    
    def __init__(self, alg, params={}):
        """
        Read in the raw data for the specified threshold curve.
        """
        self.alg = alg
        self.dl = DataLoader("thresholds")
        self.dl.read_thresholds(alg, params=params)
        self.params = copy.deepcopy(params)

    def plot_lines(self):
        """
        Plot the threshold curves and save the figure to settings.FIGDIR directory
        """
        fig = plt.figure(figsize(24,13))
        ax1 = fig.add_subplot(111)
        
        ls = []
        for i in range(len(self.dl.data)):
            l = ax1.plot(self.dl.xaxis, self.dl.data[i][1])
            plt.setp(l, linewidth=5, marker=".", markersize=30)
            ls.append(l)
        plt.legend(ls, ["n=%d"  % (str(x[0])) for x in self.dl.data], numpoints=2, handlelen=0.1, prop = font_manager.FontProperties(size=50), loc=2)
        ax1.set_xlabel(self.dl.xlabel, fontsize=50)
        ax1.set_ylabel('Probability of Sucess', fontsize=50)
        for tick in ax1.xaxis.get_major_ticks():
            tick.label1.set_fontsize(40)
        for tick in ax1.yaxis.get_major_ticks():
            tick.label1.set_fontsize(40)
        fname = settings.FIGDIR+"%s_thresholds.eps" % (self.alg)
        plt.show()
        plt.savefig(fname, dpi=2000, format="eps")
